from django.contrib.postgres.fields import ArrayField
from django.db import models


class TestQuizQuestionModelExists:
    def test_model_exists(self):
        """
        Test whether an object QuizQuestion can be imported.
        """

    def test_model_is_django_model(self):
        """
        Test if the QuizQuestion object is a Django model.
        """

        from solid_backend.quiz.models import QuizQuestion

        assert issubclass(QuizQuestion, models.Model)


class TestQuizAnswerModelExists:
    def test_model_exists(self):
        """
        Test whether an object QuizAnswer can be imported.
        """

    def test_model_is_django_model(self):
        """
        Test if the QuizAnswer object is a Django model.
        """

        from solid_backend.quiz.models import QuizAnswer

        assert issubclass(QuizAnswer, models.Model)


class TestQuizQuestionModelFields:
    """
    Test suite with basic field tests whether all fields of the QuizQuestion
    object exist and have the correct class instance.
    """

    def test_model_has_field_type(self, quiz_question_model_class):
        assert hasattr(quiz_question_model_class, "type")

    def test_model_has_field_difficulty(self, quiz_question_model_class):
        assert hasattr(quiz_question_model_class, "difficulty")

    def test_model_has_field_text(self, quiz_question_model_class):
        assert hasattr(quiz_question_model_class, "text")

    def test_model_has_field_img(self, quiz_question_model_class):
        assert hasattr(quiz_question_model_class, "img")

    def test_model_has_field_img_alt(self, quiz_question_model_class):
        assert hasattr(quiz_question_model_class, "img_alt")

    def test_model_has_field_tags(self, quiz_question_model_class):
        assert hasattr(quiz_question_model_class, "tags")

    def test_field_type_type(self, quiz_question_model_class):
        assert isinstance(
            quiz_question_model_class._meta.get_field("type"), models.CharField
        )

    def test_field_type_difficulty(self, quiz_question_model_class):
        assert isinstance(
            quiz_question_model_class._meta.get_field("difficulty"),
            models.PositiveSmallIntegerField,
        )

    def test_field_type_text(self, quiz_question_model_class):
        assert isinstance(
            quiz_question_model_class._meta.get_field("text"), models.TextField
        )

    def test_field_type_img(self, quiz_question_model_class):
        assert isinstance(
            quiz_question_model_class._meta.get_field("img"), models.ImageField
        )

    def test_field_type_img_alt(self, quiz_question_model_class):
        assert isinstance(
            quiz_question_model_class._meta.get_field("img_alt"), models.CharField
        )

    def test_field_type_tags(self, quiz_question_model_class):
        assert isinstance(quiz_question_model_class._meta.get_field("tags"), ArrayField)


class TestQuizAnswerModelFields:
    """
    Test suite with basic field tests whether all fields of the QuizAnswer
    object exist and have the correct class instance.
    """

    def test_model_has_field_question(self, quiz_answer_model_class):
        assert hasattr(quiz_answer_model_class, "question")

    def test_model_has_field_text(self, quiz_answer_model_class):
        assert hasattr(quiz_answer_model_class, "text")

    def test_model_has_field_correct(self, quiz_answer_model_class):
        assert hasattr(quiz_answer_model_class, "correct")

    def test_model_has_field_feedback_correct(self, quiz_answer_model_class):
        assert hasattr(quiz_answer_model_class, "feedback_correct")

    def test_model_has_field_feedback_incorrect(self, quiz_answer_model_class):
        assert hasattr(quiz_answer_model_class, "feedback_incorrect")

    def test_field_type_question(self, quiz_answer_model_class):
        assert isinstance(
            quiz_answer_model_class._meta.get_field("question"), models.ForeignKey
        )

    def test_field_type_text(self, quiz_answer_model_class):
        assert isinstance(
            quiz_answer_model_class._meta.get_field("text"), models.CharField
        )

    def test_field_type_correct(self, quiz_answer_model_class):
        assert isinstance(
            quiz_answer_model_class._meta.get_field("correct"), models.BooleanField
        )

    def test_field_type_feedback_correct(self, quiz_answer_model_class):
        assert isinstance(
            quiz_answer_model_class._meta.get_field("feedback_correct"),
            models.CharField,
        )

    def test_field_type_feedback_incorrect(self, quiz_answer_model_class):
        assert isinstance(
            quiz_answer_model_class._meta.get_field("feedback_incorrect"),
            models.CharField,
        )



from rest_framework.viewsets import ReadOnlyModelViewSet

from .models import Photograph
from .serializers import PhotographSerializer


class PhotographEndpoint(ReadOnlyModelViewSet):
    """
    Endpoint that provides the database table of all photographs.
    """

    queryset = Photograph.objects.all()
    serializer_class = PhotographSerializer
    name = "photograph"



from importlib import import_module

from django.conf import settings
from rest_framework import serializers

from .models import TreeNode


class TreeNodeSerializer(serializers.ModelSerializer):

    profiles = getattr(
        import_module(settings.PROFILES_SERIALIZER_MODULE), settings.PROFILES_SERIALIZER
    )(many=True)
    leaf_nodes = serializers.SerializerMethodField()

    class Meta:
        depth = 1
        model = TreeNode
        fields = ("node_name", "profiles", "leaf_nodes", "info_text")

    def get_leaf_nodes(self, obj):
        return TreeNodeSerializer(obj.get_children(), many=True).data



# Generated by Django 3.1a1 on 2020-06-08 12:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("message", "0001_implement_message_model"),
    ]

    operations = [
        migrations.AlterField(
            model_name="message",
            name="type",
            field=models.CharField(
                choices=[("CL", "Changelog"), ("SE", "Series"), ("NO", "Notice")],
                max_length=2,
            ),
        ),
    ]



from rest_framework.viewsets import ReadOnlyModelViewSet

from .models import QuizAnswer, QuizQuestion
from .serializers import QuizAnswerSerializer, QuizQuestionSerializer


class QuizQuestionEndpoint(ReadOnlyModelViewSet):
    """
    Endpoint that provides the database table of all quiz questions including their answers.
    """

    queryset = QuizQuestion.objects.all()
    serializer_class = QuizQuestionSerializer
    name = "quizquestion"


class QuizAnswerEndpoint(ReadOnlyModelViewSet):
    """
    Endpoint that provides the database table of all quiz answers including their related questions.
    """

    queryset = QuizAnswer.objects.all()
    serializer_class = QuizAnswerSerializer
    name = "quizanswer"



from django.db import models
from stdimage import JPEGField


class TestPhotographModelExists:
    """
    Test whether an object Phtotograph can be imported and is a Django model.
    """

    def test_model_exists(self):
        pass

    def test_model_is_django_model(self):
        from solid_backend.photograph.models import Photograph

        assert issubclass(Photograph, models.Model)


class TestPhotographModelFields:
    """
    Test suite with basic field tests whether all fields of the Photograph
    object exist and have the correct class instance.
    """

    def test_model_has_field_img(self, photograph_model_class):
        assert hasattr(photograph_model_class, "img")

    def test_model_has_field_img_original_width(self, photograph_model_class):
        assert hasattr(photograph_model_class, "img_original_width")

    def test_model_has_field_img_original_height(self, photograph_model_class):
        assert hasattr(photograph_model_class, "img_original_height")

    def test_model_has_field_img_original_scale(self, photograph_model_class):
        assert hasattr(photograph_model_class, "img_original_scale")

    def test_model_has_field_img_alt(self, photograph_model_class):
        assert hasattr(photograph_model_class, "img_alt")

    def test_model_has_field_description(self, photograph_model_class):
        assert hasattr(photograph_model_class, "description")

    def test_model_has_field_audio(self, photograph_model_class):
        assert hasattr(photograph_model_class, "audio")

    def test_model_has_field_audio_duration(self, photograph_model_class):
        assert hasattr(photograph_model_class, "audio_duration")

    def test_model_has_field_date(self, photograph_model_class):
        assert hasattr(photograph_model_class, "date")

    def test_model_has_field_author(self, photograph_model_class):
        assert hasattr(photograph_model_class, "author")

    def test_model_has_field_license(self, photograph_model_class):
        assert hasattr(photograph_model_class, "license")

    def test_field_type_img(self, photograph_model_class):
        assert isinstance(photograph_model_class._meta.get_field("img"), JPEGField)

    def test_field_type_img_original_width(self, photograph_model_class):
        assert isinstance(
            photograph_model_class._meta.get_field("img_original_width"),
            models.PositiveSmallIntegerField,
        )

    def test_field_type_img_original_height(self, photograph_model_class):
        assert isinstance(
            photograph_model_class._meta.get_field("img_original_height"),
            models.PositiveSmallIntegerField,
        )

    def test_field_type_img_original_scale(self, photograph_model_class):
        assert isinstance(
            photograph_model_class._meta.get_field("img_original_scale"),
            models.FloatField,
        )

    def test_field_type_img_alt(self, photograph_model_class):
        assert isinstance(
            photograph_model_class._meta.get_field("img_alt"), models.CharField
        )

    def test_field_type_description(self, photograph_model_class):
        assert isinstance(
            photograph_model_class._meta.get_field("description"), models.TextField
        )

    def test_field_type_audio(self, photograph_model_class):
        assert isinstance(
            photograph_model_class._meta.get_field("audio"), models.FileField
        )

    def test_field_type_audio_duration(self, photograph_model_class):
        assert isinstance(
            photograph_model_class._meta.get_field("audio_duration"), models.FloatField
        )

    def test_field_type_date(self, photograph_model_class):
        assert isinstance(
            photograph_model_class._meta.get_field("date"), models.DateField
        )

    def test_field_type_author(self, photograph_model_class):
        assert isinstance(
            photograph_model_class._meta.get_field("author"), models.CharField
        )

    def test_field_type_license(self, photograph_model_class):
        assert isinstance(
            photograph_model_class._meta.get_field("license"), models.CharField
        )



from django.db import models


class TestSlideshowModelExists:
    """
    Test whether an object Slideshow can be imported and is a Django model.
    """

    def test_model_exists(self):
        pass

    def test_model_is_django_model(self):
        from solid_backend.slideshow.models import Slideshow

        assert issubclass(Slideshow, models.Model)


class TestSlideshowPageModelExists:
    """
    Test whether an object SlideshowPage can be imported and is a Django model.
    """

    def test_model_exists(self):
        pass

    def test_model_is_django_model(self):
        from solid_backend.slideshow.models import SlideshowPage

        assert issubclass(SlideshowPage, models.Model)


class TestSlideshowImageModelExists:
    """
    Test whether an object SlideshowImage can be imported and is a Django model.
    """

    def test_model_exists(self):
        pass

    def test_model_is_django_model(self):
        from solid_backend.slideshow.models import SlideshowImage

        assert issubclass(SlideshowImage, models.Model)


class TestSlideshowModelFields:
    """
    Test suite with basic field tests whether all fields of the Slideshow
    object exist and have the correct class instance.
    """

    def test_model_has_field_titel(self, slideshow_model_class):
        assert hasattr(slideshow_model_class, "title")

    def test_model_has_field_img(self, slideshow_model_class):
        assert hasattr(slideshow_model_class, "img")

    def test_model_has_field_img_alt(self, slideshow_model_class):
        assert hasattr(slideshow_model_class, "img_alt")

    def test_field_type_title(self, slideshow_model_class):
        assert isinstance(
            slideshow_model_class._meta.get_field("title"), models.CharField
        )

    def test_field_type_img(self, slideshow_model_class):
        assert isinstance(
            slideshow_model_class._meta.get_field("img"), models.ImageField
        )

    def test_field_type_img_alt(self, slideshow_model_class):
        assert isinstance(
            slideshow_model_class._meta.get_field("img_alt"), models.CharField
        )


class TestSlideshowPageModelFields:
    """
    Test suite with basic field tests whether all fields of the SlideshowPage
    object exist and have the correct class instance.
    """

    def test_model_has_field_show(self, slideshow_page_model_class):
        assert hasattr(slideshow_page_model_class, "show")

    def test_model_has_field_position(self, slideshow_page_model_class):
        assert hasattr(slideshow_page_model_class, "position")

    def test_model_has_field_title(self, slideshow_page_model_class):
        assert hasattr(slideshow_page_model_class, "title")

    def test_model_has_field_text(self, slideshow_page_model_class):
        assert hasattr(slideshow_page_model_class, "text")

    def test_field_type_show(self, slideshow_page_model_class):
        assert isinstance(
            slideshow_page_model_class._meta.get_field("show"), models.ForeignKey
        )

    def test_field_type_position(self, slideshow_page_model_class):
        assert isinstance(
            slideshow_page_model_class._meta.get_field("position"),
            models.PositiveSmallIntegerField,
        )

    def test_field_type_title(self, slideshow_page_model_class):
        assert isinstance(
            slideshow_page_model_class._meta.get_field("title"), models.CharField
        )

    def test_field_type_text(self, slideshow_page_model_class):
        assert isinstance(
            slideshow_page_model_class._meta.get_field("text"), models.TextField
        )


class TestSlideshowImageModelFields:
    """
    Test suite with basic field tests whether all fields of the SlideshowImage
    object exist and have the correct class instance.
    """

    def test_model_has_field_page(self, slideshow_image_model_class):
        assert hasattr(slideshow_image_model_class, "page")

    def test_model_has_field_position(self, slideshow_image_model_class):
        assert hasattr(slideshow_image_model_class, "position")

    def test_model_has_field_title(self, slideshow_image_model_class):
        assert hasattr(slideshow_image_model_class, "title")

    def test_model_has_field_img(self, slideshow_image_model_class):
        assert hasattr(slideshow_image_model_class, "img")

    def test_model_has_field_img_alt(self, slideshow_image_model_class):
        assert hasattr(slideshow_image_model_class, "img_alt")

    def test_model_has_field_caption(self, slideshow_image_model_class):
        assert hasattr(slideshow_image_model_class, "caption")

    def test_field_type_page(self, slideshow_image_model_class):
        assert isinstance(
            slideshow_image_model_class._meta.get_field("page"), models.ForeignKey
        )

    def test_field_type_position(self, slideshow_image_model_class):
        assert isinstance(
            slideshow_image_model_class._meta.get_field("position"),
            models.PositiveSmallIntegerField,
        )

    def test_field_type_title(self, slideshow_image_model_class):
        assert isinstance(
            slideshow_image_model_class._meta.get_field("title"), models.CharField
        )

    def test_field_type_img(self, slideshow_image_model_class):
        assert isinstance(
            slideshow_image_model_class._meta.get_field("img"), models.ImageField
        )

    def test_field_type_img_alt(self, slideshow_image_model_class):
        assert isinstance(
            slideshow_image_model_class._meta.get_field("img_alt"), models.CharField
        )

    def test_field_type_caption(self, slideshow_image_model_class):
        assert isinstance(
            slideshow_image_model_class._meta.get_field("caption"), models.TextField
        )



from django.contrib import admin

from solid_backend.utility.forms import HasImgForm

from .models import Slideshow, SlideshowImage, SlideshowPage


class SlideshowPageInline(admin.TabularInline):
    model = SlideshowPage


class SlideshowImageInline(admin.TabularInline):
    model = SlideshowImage


class SlideshowAdmin(admin.ModelAdmin):
    form = HasImgForm
    list_display = ["id", "title", "img"]
    inlines = [SlideshowPageInline]


admin.site.register(Slideshow, SlideshowAdmin)


class SlideshowPageAdmin(admin.ModelAdmin):
    list_display = ["id", "show", "position", "title"]
    inlines = [SlideshowImageInline]


admin.site.register(SlideshowPage, SlideshowPageAdmin)


class SlideshowImageAdmin(admin.ModelAdmin):
    list_display = ["id", "page", "position", "title", "img"]


admin.site.register(SlideshowImage, SlideshowImageAdmin)



# Generated by Django 3.0.3 on 2020-04-09 16:23

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("slideshow", "0002_implement_slideshow_page_model"),
    ]

    operations = [
        migrations.CreateModel(
            name="SlideshowImage",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("position", models.PositiveSmallIntegerField(default=1)),
                ("title", models.CharField(max_length=100)),
                ("img", models.ImageField(upload_to="slideshow/")),
                ("img_alt", models.CharField(max_length=200)),
                ("caption", models.TextField(blank=True, default="")),
                (
                    "page",
                    models.ForeignKey(
                        db_index=False,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="images",
                        related_query_name="image",
                        to="slideshow.SlideshowPage",
                    ),
                ),
            ],
        ),
    ]



from django import forms


class HasImgForm(forms.ModelForm):
    """
    Validation if an image and an alternate text for the image are provided
    together.
    """

    def clean(self):
        img = self.cleaned_data.get("img")
        img_alt = self.cleaned_data.get("img_alt")

        if img and not img_alt:
            raise forms.ValidationError(
                "An alternate text for the image needs to be provided."
            )

        if img_alt and not img:
            raise forms.ValidationError(
                'Please select an image for upload or leave the "img alt" field empty.'
            )

        super(HasImgForm, self).clean()


class DateOrderForm(forms.ModelForm):
    """
    Validation whether a validity start date and end date are in the correct
    order.
    """

    def clean(self):
        valid_from = self.cleaned_data.get("valid_from")
        valid_to = self.cleaned_data.get("valid_to")

        if valid_to < valid_from:
            raise forms.ValidationError(
                "The validity end date must be equel with or after the start date."
            )

        super(DateOrderForm, self).clean()



from django.db import models


class TestGlossaryEntryModelExists:
    def test_model_existence(self):
        """
        This Test tests if an Object GlossaryEntry can be imported.
        :return:
        """

    def test_model_is_model(self):
        """
        Test if the GlossaryEntry Object is a Django Model
        :return:
        """
        from solid_backend.glossary.models import GlossaryEntry

        assert issubclass(GlossaryEntry, models.Model)


class TestGlossaryEntry:
    """
    This Testsuit summerizes the basic field tests:
    1. Do all fields exist
    2. Do all fields have the correct format/class instance
    """

    def test_model_has_term_field(self, glossary_entry_model_class):
        assert hasattr(glossary_entry_model_class, "term")

    def test_model_has_text_field(self, glossary_entry_model_class):
        assert hasattr(glossary_entry_model_class, "text")

    def test_model_has_links_field(self, glossary_entry_model_class):
        assert hasattr(glossary_entry_model_class, "links")

    def test_field_type_term(self, glossary_entry_model_class):
        assert isinstance(
            glossary_entry_model_class._meta.get_field("term"), models.CharField
        )

    def test_field_type_text(self, glossary_entry_model_class):
        assert isinstance(
            glossary_entry_model_class._meta.get_field("text"), models.TextField
        )

    def test_field_type_links(self, glossary_entry_model_class):
        assert isinstance(
            glossary_entry_model_class._meta.get_field("links"), models.ManyToManyField
        )



# Generated by Django 3.0.3 on 2020-04-24 09:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("slideshow", "0003_implement_slideshow_image_model"),
    ]

    operations = [
        migrations.AlterField(
            model_name="slideshowimage",
            name="caption",
            field=models.TextField(
                blank=True, default="", verbose_name="caption (Markdown)"
            ),
        ),
        migrations.AlterField(
            model_name="slideshowpage",
            name="text",
            field=models.TextField(verbose_name="text (Markdown)"),
        ),
    ]



from django.db import models


class Slideshow(models.Model):
    """
    Model for a series of pages that can be switched back and forth.
    """

    title = models.CharField(max_length=100)
    img = models.ImageField(upload_to="slideshow/", null=True, blank=True)
    img_alt = models.CharField(max_length=200, default="", blank=True)

    def __str__(self):
        return self.title


class SlideshowPage(models.Model):
    """
    Model for a page of the Slideshow model.
    """

    show = models.ForeignKey(
        to=Slideshow,
        on_delete=models.PROTECT,
        related_name="pages",
        related_query_name="page",
        db_index=False,
    )
    position = models.PositiveSmallIntegerField(
        default=1,  # validators=[validate_position_occupied]
    )
    title = models.CharField(max_length=100)
    text = models.TextField(verbose_name="text (Markdown)")

    def __str__(self):
        return self.title


class SlideshowImage(models.Model):
    """
    Model for an image for a page of the Slideshow model.
    """

    page = models.ForeignKey(
        to=SlideshowPage,
        on_delete=models.CASCADE,
        related_name="images",
        related_query_name="image",
        db_index=False,
    )
    position = models.PositiveSmallIntegerField(
        default=1,  # validators=[validate_position_occupied]
    )
    title = models.CharField(max_length=100)
    img = models.ImageField(upload_to="slideshow/")
    img_alt = models.CharField(max_length=200)
    caption = models.TextField(
        default="", blank=True, verbose_name="caption (Markdown)"
    )

    def __str__(self):
        return str(self.img)



from django.contrib import admin

from .models import GlossaryEntry


class GlossaryEntryAdmin(admin.ModelAdmin):
    list_display = ["id", "term"]


admin.site.register(GlossaryEntry, GlossaryEntryAdmin)



# Generated by Django 3.0.3 on 2020-02-11 10:34

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="GlossaryEntry",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("term", models.CharField(max_length=100)),
                ("text", models.TextField()),
                (
                    "img",
                    models.ImageField(
                        blank=True, null=True, upload_to="glossary/images/"
                    ),
                ),
                ("img_alt", models.CharField(blank=True, default="", max_length=200)),
                (
                    "links",
                    models.ManyToManyField(blank=True, to="glossary.GlossaryEntry"),
                ),
            ],
        ),
    ]



from django.contrib.contenttypes.fields import GenericRelation
from django.db import models
from django.utils.translation import ugettext_lazy as _
from mptt.models import MPTTModel, TreeForeignKey

from solid_backend.photograph.models import Photograph

# Custom Models, representing the actual data of a profile, implement here.
# At least one model needs to have a ForeignKey field to the TreeNode model
# with related_name="profiles". If not, the profiles endpoint will throw an
# error.


class BaseProfile(models.Model):
    """
    A base model used for inharitance such that we have a Generic Many (Photograph) to One (Profile)
    Relation.
    """

    photographs = GenericRelation(Photograph, null=True)

    class Meta:
        abstract = True


# Model for the tree representation of the profiles
class TreeNode(MPTTModel):
    node_name = models.CharField(
        max_length=200, verbose_name=_("node name"), unique=True
    )
    parent = TreeForeignKey(
        "self",
        on_delete=models.CASCADE,
        null=True,
        blank=True,
        related_name="leaf_nodes",
    )

    info_text = models.TextField(max_length=500, blank=True)
    is_top_level = models.BooleanField(default=False)

    class Meta:
        verbose_name = _("Tree Node")
        verbose_name_plural = _("Tree Nodes")

    def __str__(self):
        return self.node_name



from rest_framework.routers import SimpleRouter

from .views import SlideshowEndpoint, SlideshowImageEndpoint, SlideshowPageEndpoint

app_name = "slideshow"
router = SimpleRouter()
router.register(r"slideshows", SlideshowEndpoint)
router.register(r"slideshowpages", SlideshowPageEndpoint)
router.register(r"slideshowimages", SlideshowImageEndpoint)
urlpatterns = []
urlpatterns += router.urls



from rest_framework.routers import SimpleRouter

from .views import MessageEndpoint

app_name = "message"
router = SimpleRouter()
router.register(r"messages", MessageEndpoint)
urlpatterns = []
urlpatterns += router.urls



# Generated by Django 3.1b1 on 2020-06-24 11:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("photograph", "0001_implement_photograph_model"),
    ]

    operations = [
        migrations.AddField(
            model_name="photograph",
            name="audio",
            field=models.FileField(blank=True, null=True, upload_to="audio/"),
        ),
        migrations.AddField(
            model_name="photograph",
            name="audio_duration",
            field=models.FloatField(editable=False, null=True),
        ),
    ]



from rest_framework.routers import SimpleRouter

from .views import QuizAnswerEndpoint, QuizQuestionEndpoint

app_name = "quiz"
router = SimpleRouter()
router.register(r"quizquestions", QuizQuestionEndpoint)
router.register(r"quizanswers", QuizAnswerEndpoint)
urlpatterns = []
urlpatterns += router.urls



from datetime import date

from rest_framework.viewsets import ReadOnlyModelViewSet

from .models import Message
from .serializers import MessageSerializer


class MessageEndpoint(ReadOnlyModelViewSet):
    """
    Endpoint that provides the database table of currently valid messages.
    """

    queryset = Message.objects.filter(
        valid_from__lte=date.today(), valid_to__gte=date.today()
    )
    serializer_class = MessageSerializer
    name = "message"



from rest_framework import serializers

from .models import GlossaryEntry


class GlossaryEntrySerializer(serializers.ModelSerializer):
    class Meta:
        model = GlossaryEntry
        fields = "__all__"



# Generated by Django 3.0.3 on 2020-03-18 10:54

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="QuizQuestion",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "type",
                    models.CharField(
                        choices=[
                            ("SC", "Single Choice"),
                            ("MC", "Multiple Choice"),
                            ("DD", "Drag and Drop"),
                            ("RG", "Ranking"),
                            ("HS", "Hotspot"),
                        ],
                        max_length=2,
                    ),
                ),
                (
                    "difficulty",
                    models.PositiveSmallIntegerField(
                        choices=[
                            (1, "Neuling"),
                            (2, "Einsteiger"),
                            (3, "Fortgeschrittener"),
                            (4, "Erfahrener"),
                            (5, "Experte"),
                        ]
                    ),
                ),
                ("text", models.TextField()),
                ("img", models.ImageField(blank=True, null=True, upload_to="quiz/")),
                ("img_alt", models.CharField(blank=True, default="", max_length=200)),
                (
                    "tags",
                    django.contrib.postgres.fields.ArrayField(
                        base_field=models.CharField(max_length=100),
                        blank=True,
                        default=list,
                        help_text="If you want to add more than one tag, seperate them with commas.",
                        size=None,
                    ),
                ),
            ],
        ),
    ]



from django.conf import settings
from django.core.mail import send_mail
from rest_framework import generics, response, status

from .serializers import ContactSerializer


class ContactView(generics.GenericAPIView):
    serializer_class = ContactSerializer

    permission_classes = ()

    def post(self, request, *args, **kwargs):
        serializer = ContactSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        data = serializer.data

        message = send_mail(
            subject=data["subject"],
            message=data["message"],
            from_email="{0} <{1}>".format(serializer["name"], data["email"]),
            recipient_list=[settings.SYSTEM_EMAIL],
            fail_silently=False,
        )
        if not message:
            return response.Response(status=status.HTTP_400_BAD_REQUEST)
        return response.Response(data=serializer)



from django.db import models


class TestMessageModelExists:
    """
    Test whether an object Message can be imported and is a Django model.
    """

    def test_model_exists(self):
        pass

    def test_model_is_django_model(self):
        from solid_backend.message.models import Message

        assert issubclass(Message, models.Model)


class TestMessageModelFields:
    """
    Test suite with basic field tests whether all fields of the Message
    object exist and have the correct class instance.
    """

    def test_model_has_field_type(self, message_model_class):
        assert hasattr(message_model_class, "type")

    def test_model_has_field_title(self, message_model_class):
        assert hasattr(message_model_class, "title")

    def test_model_has_field_text(self, message_model_class):
        assert hasattr(message_model_class, "text")

    def test_model_has_field_img(self, message_model_class):
        assert hasattr(message_model_class, "img")

    def test_model_has_field_img_alt(self, message_model_class):
        assert hasattr(message_model_class, "img_alt")

    def test_model_has_field_valid_from(self, message_model_class):
        assert hasattr(message_model_class, "valid_from")

    def test_model_has_field_valid_to(self, message_model_class):
        assert hasattr(message_model_class, "valid_to")

    def test_field_type_type(self, message_model_class):
        assert isinstance(message_model_class._meta.get_field("type"), models.CharField)

    def test_field_type_title(self, message_model_class):
        assert isinstance(
            message_model_class._meta.get_field("title"), models.CharField
        )

    def test_field_type_text(self, message_model_class):
        assert isinstance(message_model_class._meta.get_field("text"), models.TextField)

    def test_field_type_img(self, message_model_class):
        assert isinstance(message_model_class._meta.get_field("img"), models.ImageField)

    def test_field_type_img_alt(self, message_model_class):
        assert isinstance(
            message_model_class._meta.get_field("img_alt"), models.CharField
        )

    def test_field_type_valid_from(self, message_model_class):
        assert isinstance(
            message_model_class._meta.get_field("valid_from"), models.DateField
        )

    def test_field_type_valid_to(self, message_model_class):
        assert isinstance(
            message_model_class._meta.get_field("valid_to"), models.DateField
        )



from rest_framework import serializers

from .models import Slideshow, SlideshowImage, SlideshowPage


class SlideshowImageLessSerializer(serializers.ModelSerializer):
    class Meta:
        model = SlideshowImage
        fields = ["id", "position", "title", "img", "img_alt", "caption"]


class SlideshowPageLessSerializer(serializers.ModelSerializer):
    images = SlideshowImageLessSerializer(many=True)

    class Meta:
        model = SlideshowPage
        fields = ["id", "position", "title", "text", "images"]


class SlideshowSerializer(serializers.ModelSerializer):
    pages = SlideshowPageLessSerializer(many=True)

    class Meta:
        model = Slideshow
        fields = "__all__"


class SlideshowPageSerializer(serializers.ModelSerializer):
    images = SlideshowImageLessSerializer(many=True)

    class Meta:
        model = SlideshowPage
        fields = "__all__"


class SlideshowImageSerializer(serializers.ModelSerializer):
    class Meta:
        model = SlideshowImage
        fields = "__all__"



# Generated by Django 3.0.3 on 2020-04-24 09:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("quiz", "0002_implement_quiz_answer_model"),
    ]

    operations = [
        migrations.AlterField(
            model_name="quizanswer",
            name="text",
            field=models.CharField(max_length=200, verbose_name="text (Markdown)"),
        ),
        migrations.AlterField(
            model_name="quizquestion",
            name="text",
            field=models.TextField(verbose_name="text (Markdown)"),
        ),
    ]



from datetime import date

from django.db import models


class Message(models.Model):
    """
    Model for a message that is displayed to the users when the app starts.
    """

    MTYPE_CHOICES = [("CL", "Changelog"), ("SE", "Series"), ("NO", "Notice")]

    type = models.CharField(max_length=2, choices=MTYPE_CHOICES)
    title = models.CharField(max_length=100)
    text = models.TextField(default="", blank=True, verbose_name="text (Markdown)")
    img = models.ImageField(upload_to="message/", null=True, blank=True)
    img_alt = models.CharField(max_length=200, default="", blank=True)
    valid_from = models.DateField(default=date.today)
    valid_to = models.DateField(default=date.today)

    def __str__(self):
        return self.title



from django.contrib import admin

from solid_backend.utility.forms import DateOrderForm, HasImgForm

from .models import Message


class MessageForm(HasImgForm, DateOrderForm):
    pass


class MessageAdmin(admin.ModelAdmin):
    form = MessageForm
    list_display = ["id", "type", "title", "valid_from", "valid_to", "img"]


admin.site.register(Message, MessageAdmin)



from django.conf.urls import url
from rest_framework.routers import SimpleRouter

from .views import FieldMappingEndpoint, ProfilesEndpoint

app_name = "content"

router = SimpleRouter()
router.register(r"profiles", ProfilesEndpoint, basename="profiles")

urlpatterns = [
    url(r"field-mapping", FieldMappingEndpoint.as_view(), name="field-mapping"),
]

urlpatterns += router.urls



# Generated by Django 3.0.7 on 2020-07-07 13:04

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("photograph", "0002_add_audio_fields"),
    ]

    operations = [
        migrations.AddField(
            model_name="photograph",
            name="content_type",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="contenttypes.ContentType",
            ),
        ),
        migrations.AddField(
            model_name="photograph",
            name="object_id",
            field=models.PositiveIntegerField(default=0),
        ),
    ]



# Generated by Django 3.0.3 on 2020-03-20 15:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("quiz", "0001_implement_quiz_question_model"),
    ]

    operations = [
        migrations.CreateModel(
            name="QuizAnswer",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("text", models.CharField(max_length=200)),
                ("correct", models.BooleanField()),
                (
                    "feedback_correct",
                    models.CharField(blank=True, default="", max_length=400),
                ),
                (
                    "feedback_incorrect",
                    models.CharField(blank=True, default="", max_length=400),
                ),
                (
                    "question",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="answers",
                        related_query_name="answer",
                        to="quiz.QuizQuestion",
                    ),
                ),
            ],
        ),
    ]



from rest_framework.routers import SimpleRouter

from .views import PhotographEndpoint

app_name = "photograph"
router = SimpleRouter()
router.register(r"photographs", PhotographEndpoint)
urlpatterns = []
urlpatterns += router.urls



# Generated by Django 3.0.3 on 2020-04-24 09:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("glossary", "0002_update_image_upload_path"),
    ]

    operations = [
        migrations.AlterField(
            model_name="glossaryentry",
            name="text",
            field=models.TextField(verbose_name="text (Markdown)"),
        ),
    ]



# Generated by Django 3.0.6 on 2020-05-26 14:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("glossary", "0003_add_verbose_name_to_text_field"),
    ]

    operations = [
        migrations.RemoveField(model_name="glossaryentry", name="img",),
        migrations.RemoveField(model_name="glossaryentry", name="img_alt",),
    ]



from django import forms
from mutagen import File

from .models import Photograph


class PhotographForm(forms.ModelForm):
    """
    Calculation of the scale and determination of the audio duration is provided.
    """

    LENGTH_UNIT_CHOICES = [
        (1.00, "m"),
        (0.01, "cm"),
        (0.001, "mm"),
    ]
    length_value = forms.FloatField(
        min_value=0.000001, required=False, label="Scale", help_text="Längenwert",
    )
    length_unit = forms.TypedChoiceField(
        coerce=float,
        choices=LENGTH_UNIT_CHOICES,
        initial=LENGTH_UNIT_CHOICES[1][0],
        label="",
        help_text="Längeneinheit",
    )
    pixel_number = forms.IntegerField(
        max_value=32767,
        min_value=0,
        required=False,
        label="",
        help_text='Pixelanzahl ("0" löscht den Wert von Scale)',
    )

    def save(self, commit=True):
        length_value = self.cleaned_data.get("length_value")
        length_unit = self.cleaned_data.get("length_unit")
        pixel_number = self.cleaned_data.get("pixel_number")

        instance = super(PhotographForm, self).save(commit=False)

        if length_value and pixel_number:
            instance.img_original_scale = length_value * length_unit / pixel_number

        if pixel_number == 0:
            instance.img_original_scale = None

        if instance.audio:
            instance.audio_duration = File(instance.audio).info.length
        else:
            instance.audio_duration = None

        if commit:
            instance.save()

        return instance



from django.contrib.postgres.fields import ArrayField
from django.db import models


class QuizQuestion(models.Model):
    """
    Model for a quesiton in the quiz of the app.
    """

    QTYPE_CHOICES = [
        ("SC", "Single Choice"),
        ("MC", "Multiple Choice"),
        ("DD", "Drag and Drop"),
        ("RG", "Ranking"),
        ("HS", "Hotspot"),
    ]
    QDIFFICULTY_CHOICES = [
        (1, "Neuling"),
        (2, "Einsteiger"),
        (3, "Fortgeschrittener"),
        (4, "Erfahrener"),
        (5, "Experte"),
    ]

    type = models.CharField(max_length=2, choices=QTYPE_CHOICES)
    difficulty = models.PositiveSmallIntegerField(choices=QDIFFICULTY_CHOICES)
    text = models.TextField(verbose_name="text (Markdown)")
    img = models.ImageField(upload_to="quiz/", null=True, blank=True)
    img_alt = models.CharField(max_length=200, default="", blank=True)
    tags = ArrayField(
        base_field=models.CharField(max_length=100),
        default=list,
        blank=True,
        help_text="If you want to add more than one tag, seperate them with commas.",
    )

    def __str__(self):
        return self.text


class QuizAnswer(models.Model):
    """
    Model for an answer to a question of the QuizQuestion model.
    """

    question = models.ForeignKey(
        to=QuizQuestion,
        on_delete=models.CASCADE,
        related_name="answers",
        related_query_name="answer",
    )
    text = models.CharField(max_length=200, verbose_name="text (Markdown)")
    correct = models.BooleanField()
    feedback_correct = models.CharField(max_length=400, default="", blank=True)
    feedback_incorrect = models.CharField(max_length=400, default="", blank=True)



# Generated by Django 3.0.4 on 2020-03-21 14:20

import django.db.models.deletion
import mptt.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="TreeNode",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "node_name",
                    models.CharField(
                        max_length=200, unique=True, verbose_name="node name"
                    ),
                ),
                ("info_text", models.TextField(blank=True, max_length=500)),
                ("is_top_level", models.BooleanField(default=False)),
                ("lft", models.PositiveIntegerField(editable=False)),
                ("rght", models.PositiveIntegerField(editable=False)),
                ("tree_id", models.PositiveIntegerField(db_index=True, editable=False)),
                ("level", models.PositiveIntegerField(editable=False)),
                (
                    "parent",
                    mptt.fields.TreeForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="leaf_nodes",
                        to="content.TreeNode",
                    ),
                ),
            ],
            options={"verbose_name": "Tree Node", "verbose_name_plural": "Tree Nodes",},
        ),
    ]



from rest_framework.routers import SimpleRouter

from .views import GlossaryEntryEndpoint

app_name = "glossary"
router = SimpleRouter()
router.register(r"glossaryentries", GlossaryEntryEndpoint)
urlpatterns = []
urlpatterns += router.urls



from rest_framework.viewsets import ReadOnlyModelViewSet

from .models import Slideshow, SlideshowImage, SlideshowPage
from .serializers import (
    SlideshowImageSerializer,
    SlideshowPageSerializer,
    SlideshowSerializer,
)


class SlideshowEndpoint(ReadOnlyModelViewSet):
    """
    Endpoint that provides the database table of all slideshows including their pages and images.
    """

    queryset = Slideshow.objects.all()
    serializer_class = SlideshowSerializer
    name = "slideshow"


class SlideshowPageEndpoint(ReadOnlyModelViewSet):
    """
    Endpoint that provides the database table of all slideshow pages including their images.
    """

    queryset = SlideshowPage.objects.all()
    serializer_class = SlideshowPageSerializer
    name = "slideshowpage"


class SlideshowImageEndpoint(ReadOnlyModelViewSet):
    """
    Endpoint that provides the database table of all slideshow images.
    """

    queryset = SlideshowImage.objects.all()
    serializer_class = SlideshowImageSerializer
    name = "slideshowimage"



from rest_framework import serializers

from .models import Photograph


# Class derived from django-stdimage-serializer 0.1.2
class StdImageField(serializers.ImageField):
    """
    Get all the variations of the StdImageField
    """

    def to_native(self, obj):
        return self.get_variations_urls(obj)

    def to_representation(self, obj):
        return self.get_variations_urls(obj)

    def get_variations_urls(self, obj):
        """
        Get all the logo urls.
        """

        # Initiate return object
        return_object = {}

        # Get the field of the object
        field = obj.field

        # A lot of ifs going araound, first check if it has the field variations
        if hasattr(field, "variations"):
            # Get the variations
            variations = field.variations
            # Go through the variations dict
            for key in variations.keys():
                # Just to be sure if the stdimage object has it stored in the obj
                if hasattr(obj, key):
                    # get the by stdimage properties
                    field_obj = getattr(obj, key, None)
                    if field_obj and hasattr(field_obj, "url"):
                        # store it, with the name of the variation type into our return object
                        return_object[key] = super(
                            StdImageField, self
                        ).to_representation(field_obj)

        # Also include the original (if possible)
        if hasattr(obj, "url"):
            return_object["original"] = super(StdImageField, self).to_representation(
                obj
            )

        return return_object


class PhotographSerializer(serializers.ModelSerializer):
    img = StdImageField()

    class Meta:
        model = Photograph
        fields = "__all__"



from rest_framework import serializers


class ContactSerializer(serializers.Serializer):
    name = serializers.CharField()
    email = serializers.EmailField()
    subject = serializers.CharField()
    message = serializers.CharField()



from datetime import date

from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.db import models
from stdimage import JPEGField


class Photograph(models.Model):
    """
    Model for a photograph.
    """

    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE, null=True)
    object_id = models.PositiveIntegerField(default=0)
    profile = GenericForeignKey("content_type", "object_id")
    img = JPEGField(
        upload_to="photograph/",
        width_field="img_original_width",
        height_field="img_original_height",
        variations={
            "large": (1200, 800),
            "medium": (900, 600),
            "small": (600, 400),
            "thumbnail": (100, 100, True),
        },
        db_index=True,
        delete_orphans=True,
    )
    # dzi_file = models.FileField(upload_to="dzi_files/", null=True, blank=True, editable=False)
    img_original_width = models.PositiveSmallIntegerField(editable=False)
    img_original_height = models.PositiveSmallIntegerField(editable=False)
    img_original_scale = models.FloatField(verbose_name="scale", null=True, blank=True,)

    img_alt = models.CharField(max_length=200)
    description = models.TextField(
        default="", blank=True, verbose_name="description (Markdown)"
    )
    audio = models.FileField(upload_to="audio/", null=True, blank=True)
    audio_duration = models.FloatField(null=True, editable=False)

    # location =
    date = models.DateField(
        null=True, blank=True, help_text="Datum der Lichtbildaufnahme"
    )
    author = models.CharField(max_length=100, default="", blank=True)
    license = models.CharField(max_length=100, default="", blank=True)

    def __str__(self):
        return str(self.img)



# Generated by Django 3.0.6 on 2020-05-26 13:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("slideshow", "0004_add_verbose_name_to_text_fields"),
    ]

    operations = [
        migrations.AddField(
            model_name="slideshow",
            name="img",
            field=models.ImageField(blank=True, null=True, upload_to="slideshow/"),
        ),
        migrations.AddField(
            model_name="slideshow",
            name="img_alt",
            field=models.CharField(blank=True, default="", max_length=200),
        ),
    ]



from django.db import models


class GlossaryEntry(models.Model):
    """
    Defines a model for an entry in the glossary that is displayed in the app.
    """

    term = models.CharField(max_length=100)
    text = models.TextField(verbose_name="text (Markdown)")
    links = models.ManyToManyField("self", symmetrical=False, blank=True)

    def __str__(self):
        return self.term



# Generated by Django 3.0.3 on 2020-04-24 09:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("glossary", "0001_implement_glossary_entry_model"),
    ]

    operations = [
        migrations.AlterField(
            model_name="glossaryentry",
            name="img",
            field=models.ImageField(blank=True, null=True, upload_to="glossary/"),
        ),
    ]



from rest_framework.viewsets import ReadOnlyModelViewSet

from .models import GlossaryEntry
from .serializers import GlossaryEntrySerializer


class GlossaryEntryEndpoint(ReadOnlyModelViewSet):
    """
    Endpoint that provides the database table of all glossary entries.
    """

    queryset = GlossaryEntry.objects.all()
    serializer_class = GlossaryEntrySerializer
    name = "glossaryentry"



from rest_framework import serializers


class TestContactSerializerFields:
    """
    Test suite with basic field tests whether all fields of the Contact object exist and
    have the correct class instance.
    """

    def test_serializer_has_field_name(self, contact_serializer_field_dict):
        assert contact_serializer_field_dict.get("name")

    def test_serializer_has_field_email(self, contact_serializer_field_dict):
        assert contact_serializer_field_dict.get("email")

    def test_serializer_has_field_subject(self, contact_serializer_field_dict):
        assert contact_serializer_field_dict.get("subject")

    def test_serializer_has_field_message(self, contact_serializer_field_dict):
        assert contact_serializer_field_dict.get("message")

    def test_field_type_name(self, contact_serializer_field_dict):
        assert isinstance(
            contact_serializer_field_dict.get("name"), serializers.CharField
        )

    def test_field_type_email(self, contact_serializer_field_dict):
        assert isinstance(
            contact_serializer_field_dict.get("email"), serializers.EmailField
        )

    def test_field_type_subject(self, contact_serializer_field_dict):
        assert isinstance(
            contact_serializer_field_dict.get("subject"), serializers.CharField
        )

    def test_field_type_message(self, contact_serializer_field_dict):
        assert isinstance(
            contact_serializer_field_dict.get("message"), serializers.CharField
        )



from django.conf import settings
from rest_framework.views import APIView, Response
from rest_framework.viewsets import ReadOnlyModelViewSet

from .models import TreeNode
from .serializers import TreeNodeSerializer

# Create your views here.


class ProfilesEndpoint(ReadOnlyModelViewSet):
    model = TreeNode
    queryset = model.objects.root_nodes()
    serializer_class = TreeNodeSerializer
    name = "profiles"
    app = "api"


class FieldMappingEndpoint(APIView):
    data = settings.DATABASE_FIELD_MAPPING

    def get(self, request):
        return Response(data=self.data)



from django.contrib import admin

from solid_backend.utility.forms import HasImgForm

from .models import QuizAnswer, QuizQuestion


class QuizAnswerInline(admin.TabularInline):
    model = QuizAnswer


class QuizQuestionAdmin(admin.ModelAdmin):
    form = HasImgForm
    list_display = ["id", "text"]
    inlines = [
        QuizAnswerInline,
    ]


admin.site.register(QuizQuestion, QuizQuestionAdmin)


class QuizAnswerAdmin(admin.ModelAdmin):
    list_display = ["id", "question", "text", "correct"]


admin.site.register(QuizAnswer, QuizAnswerAdmin)



from rest_framework import serializers

from .models import QuizAnswer, QuizQuestion


class QuizQuestionLessSerializer(serializers.ModelSerializer):
    class Meta:
        model = QuizQuestion
        fields = "__all__"


class QuizAnswerLessSerializer(serializers.ModelSerializer):
    class Meta:
        model = QuizAnswer
        fields = "__all__"


class QuizQuestionSerializer(serializers.ModelSerializer):
    answers = QuizAnswerLessSerializer(many=True)

    class Meta:
        model = QuizQuestion
        fields = "__all__"


class QuizAnswerSerializer(serializers.ModelSerializer):
    question = QuizQuestionLessSerializer()

    class Meta:
        model = QuizAnswer
        fields = "__all__"



from django.urls import include, path

urlpatterns = [
    path("", include("solid_backend.contact.urls")),
    path("", include("solid_backend.content.urls")),
    path("", include("solid_backend.glossary.urls")),
    path("", include("solid_backend.message.urls")),
    path("", include("solid_backend.quiz.urls")),
    path("", include("solid_backend.slideshow.urls")),
]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['solid_backend',
 'solid_backend.contact',
 'solid_backend.contact.migrations',
 'solid_backend.contact.tests',
 'solid_backend.contact.tests.conftest_files',
 'solid_backend.content',
 'solid_backend.content.migrations',
 'solid_backend.glossary',
 'solid_backend.glossary.migrations',
 'solid_backend.glossary.tests',
 'solid_backend.glossary.tests.conftest_files',
 'solid_backend.message',
 'solid_backend.message.migrations',
 'solid_backend.message.tests',
 'solid_backend.message.tests.conftest_files',
 'solid_backend.photograph',
 'solid_backend.photograph.migrations',
 'solid_backend.photograph.tests',
 'solid_backend.photograph.tests.conftest_files',
 'solid_backend.quiz',
 'solid_backend.quiz.migrations',
 'solid_backend.quiz.tests',
 'solid_backend.quiz.tests.conftest_files',
 'solid_backend.slideshow',
 'solid_backend.slideshow.migrations',
 'solid_backend.slideshow.tests',
 'solid_backend.slideshow.tests.conftest_files',
 'solid_backend.utility']

package_data = \
{'': ['*']}

install_requires = \
['django-cleanup==4.0.0',
 'django-mptt==0.11.0',
 'django-stdimage>=5.1.1,<6.0.0',
 'django>=3.0.7,<4.0.0',
 'djangorestframework==3.11.0',
 'mutagen>=1.44.0,<2.0.0',
 'pillow==7.1.2',
 'psycopg2-binary>=2.8.5,<3.0.0']

setup_kwargs = {
    'name': 'solid-backend',
    'version': '0.1.4',
    'description': 'Clean Django App for E-Learning apllication with ',
    'long_description': '# S.O.L.I.D-Backend\n\n## What is S.O.L.I.D?\n\n\n## Documentation\n\nComing soon...\n\n## Coverage\n\nComing soon...\n\n## Try it out and local development\n\nFor a How-To guide see the README in the sample_project directory.\n\n',
    'author': 'Christian Grossm\xc3\xbcller',
    'author_email': 'chgad.games@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/zentrumnawi/solid-backend',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



import pytest

from solid_backend.quiz.models import QuizAnswer, QuizQuestion


@pytest.fixture
def quiz_question_model_class():
    return QuizQuestion


@pytest.fixture
def quiz_answer_model_class():
    return QuizAnswer



from django.contrib import admin
from django.contrib.contenttypes.admin import GenericTabularInline

from .forms import PhotographForm
from .models import Photograph


class PhotographInline(GenericTabularInline):
    model = Photograph


class PhotographAdmin(admin.ModelAdmin):
    form = PhotographForm
    fields = [
        "img",
        ("length_value", "length_unit", "pixel_number"),
        "img_alt",
        "description",
        "audio",
        "date",
        "author",
        "license",
    ]
    list_display = ["id", "img", "img_original_scale", "author"]


admin.site.register(Photograph, PhotographAdmin)



import pytest

from solid_backend.slideshow.models import Slideshow, SlideshowImage, SlideshowPage


@pytest.fixture
def slideshow_model_class():
    return Slideshow


@pytest.fixture
def slideshow_page_model_class():
    return SlideshowPage


@pytest.fixture
def slideshow_image_model_class():
    return SlideshowImage



# Generated by Django 3.1a1 on 2020-06-15 09:00

import stdimage.models
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Photograph",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "img",
                    stdimage.models.JPEGField(
                        db_index=True,
                        height_field="img_original_height",
                        upload_to="photograph/",
                        width_field="img_original_width",
                    ),
                ),
                (
                    "img_original_width",
                    models.PositiveSmallIntegerField(editable=False),
                ),
                (
                    "img_original_height",
                    models.PositiveSmallIntegerField(editable=False),
                ),
                (
                    "img_original_scale",
                    models.FloatField(blank=True, null=True, verbose_name="scale",),
                ),
                ("img_alt", models.CharField(max_length=200)),
                (
                    "description",
                    models.TextField(
                        blank=True, default="", verbose_name="description (Markdown)"
                    ),
                ),
                (
                    "date",
                    models.DateField(
                        blank=True, help_text="Datum der Lichtbildaufnahme", null=True
                    ),
                ),
                ("author", models.CharField(blank=True, default="", max_length=100)),
                ("license", models.CharField(blank=True, default="", max_length=100)),
            ],
        ),
    ]



# Generated by Django 3.0.3 on 2020-04-15 17:41

import datetime

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Message",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "type",
                    models.CharField(
                        choices=[
                            ("CL", "Changlog"),
                            ("SE", "Series"),
                            ("NO", "Notice"),
                        ],
                        max_length=2,
                    ),
                ),
                ("title", models.CharField(max_length=100)),
                (
                    "text",
                    models.TextField(
                        blank=True, default="", verbose_name="text (Markdown)"
                    ),
                ),
                ("img", models.ImageField(blank=True, null=True, upload_to="message/")),
                ("img_alt", models.CharField(blank=True, default="", max_length=200)),
                ("valid_from", models.DateField(default=datetime.date.today)),
                ("valid_to", models.DateField(default=datetime.date.today)),
            ],
        ),
    ]
